@@ -5,9 +5,16 @@ PRAXIS_NS = 'http://www.praxis.com.mx/'
 
 
 class Respuesta(object):
-    def __new__(cls, mensaje_xml):
-        respuesta = etree.Element('respuesta', xlmns=PRAXIS_NS)
-        mensaje = etree.tostring(mensaje_xml, xml_declaration=True, encoding='cp850')
+    def __new__(cls, element):
+        respuesta = etree.Element(
+            etree.QName(PRAXIS_NS, 'respuesta'),
+            nsmap={None: PRAXIS_NS},
+        )
+        mensaje = etree.tostring(
+            element,
+            xml_declaration=True,
+            encoding='cp850',
+        )
         respuesta.text = mensaje
         return respuesta
 
@@ -29,7 +36,7 @@ class Envelope(object):
 
 class RespuestaRequest(object):
     def __new__(cls, mensaje, as_string=True):
-        envelope = Envelope(Body(Respuesta(mensaje.build_xml())))
+        envelope = Respuesta(mensaje.build_xml())
         if not as_string:
             return envelope
         return etree.tostring(envelope, xml_declaration=True)
