@@ -27,7 +27,9 @@ class Orden(BaseModel):
     op_tipo_orden: types.TipoOrdenPago
     op_prioridad: types.PrioridadOrdenPago
     op_me_clave: types.MedioEntregaOrdenPago
-    op_topologia: types.TopologiaOrdenPago = types.TopologiaOrdenPago.notify_on_payment_settlement  # noqa: E501
+    op_topologia: types.TopologiaOrdenPago = (
+        types.TopologiaOrdenPago.notify_on_payment_settlement
+    )
     op_usu_clave: str
 
     op_firma_dig: str
@@ -111,7 +113,12 @@ class Orden(BaseModel):
         mensaje = etree.Element('mensaje', categoria=self.categoria)
         orden_pago = etree.SubElement(mensaje, 'ordenpago')
 
-        for element, value in self.dict(exclude_none=True, exclude={'categoria', 'op_ord_clave'}).items():  # noqa: WPS110, WPS221, E501
+        elements = self.dict(
+            exclude_none=True,
+            exclude={'categoria', 'op_ord_clave'},
+        )
+
+        for element, value in elements.items():  # noqa: WPS110
             if element in self.__fields__:
                 if element == 'op_firma_dig':
                     subelement = etree.SubElement(orden_pago, 'opFirmaDig')
@@ -124,15 +131,15 @@ class Orden(BaseModel):
         return mensaje
 
     @classmethod
-    def parse_xml(cls, mensaje_xml):
-        orden_xml = mensaje_xml.find('ordenpago')
+    def parse_xml(cls, mensaje):
+        ordenpago = mensaje.find('ordenpago')
 
         orden_data = {
-            'id': orden_xml.attrib['Id'],
-            'categoria': mensaje_xml.attrib['categoria'],
+            'id': ordenpago.attrib['Id'],
+            'categoria': mensaje.attrib['categoria'],
         }
 
-        for element in orden_xml.getchildren():
+        for element in ordenpago.getchildren():
             tag = to_snake_case(element.tag)
             if tag in cls.__fields__:
                 orden_data[tag] = element.text
